datastructuretools.BreakPointFunction
=====================================

.. abjad-lineage:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction

.. autoclass:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.bpf
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.clip_x_axis
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.clip_y_axis
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.concatenate
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.dc_bias
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.get_y_at_x
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.gnuplot_format
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.invert
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.normalize_axes
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.reflect
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.remove_dc_bias
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.scale_x_axis
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.scale_y_axis
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.set_y_at_x
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.tessalate_by_ratio
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.x_center
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.x_range
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.x_values
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.y_center
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.y_range
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__add__
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__div__
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__eq__
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__getitem__
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__mul__
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__ne__
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__repr__
      ~abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__sub__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.bpf
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.dc_bias
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.gnuplot_format
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.x_center
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.x_range
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.x_values
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.y_center
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.y_range
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.clip_x_axis
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.clip_y_axis
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.concatenate
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.get_y_at_x
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.invert
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.normalize_axes
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.reflect
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.remove_dc_bias
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.scale_x_axis
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.scale_y_axis
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.set_y_at_x
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.tessalate_by_ratio
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__add__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__div__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__mul__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.BreakPointFunction.BreakPointFunction.BreakPointFunction.__sub__
   :noindex:
